# Marion, The Documents Factory

Marion is a styled documents factory using HTML/CSS Django templates and a
headless browser that render them as PDF files. It can be used as a library or
an application in your Django project.

## Documentation

We try our best to maintain an up-to-date reference documentation for this
project. If you intend to install, test or contribute to Marion or Howard, we
invite you to read this [documentation](https://openfun.github.io/marion) and
give us feedback if some parts are unclear or your use case is not (or poorly)
covered.

## Contributing

This project is intended to be community-driven, so please, do not hesitate to
get in touch if you have any questions related to our implementation or design
decisions.

We try to raise our code quality standards and expect contributors to follow
the recommendations from our
[handbook](https://openfun.gitbooks.io/handbook/content).

## License

This work is released under the MIT License (see [LICENSE](./LICENSE))
